Archive

Struct Archive 

pub struct Archive<R> { /* private fields */ }
A structure representing a CPT archive

Archives are created by opening a file on disk or by wrapping a seekable reader using the try_from function.

Implementations

Source

impl<R> Archive<R>

pub const TYPE_CODE: FourCC

Macintosh type code used by CPT files (PACT)

pub const CREATOR_CODE: FourCC

Macintosh creator code used by CPT files (CPCT)

pub fn into_inner(self) -> R

Returns the underlying reader, note that it’s read position will have changed from when you passed it in

Source

impl<A: Read + Seek> Archive<Reader<A>>

pub fn try_from(inner: A) -> Result<Self, Error>

Creates an Archive from the given reader

Source

impl<R: Read + Seek> Archive<R>

pub fn iter(&self) -> Result<EntryIterator<R>, Error>

Creates an iterator over all archive entries.

This method panics if another [EntryIterator] is currently alive for this archive to avoid over sharing the underlying reader’s seek position.

pub fn verify_entry(&mut self, entry: &Entry) -> Result<(), VerificationError>

Verifies the given entry, returning a verification error if anything goes wrong

pub fn open_entry( &mut self, entry: &Entry, fork: Fork, ) -> Result<EntryReader<'_, R>, Error>

Opens the specified fork of an entry for reading

Source

impl Archive<Reader<File>>

pub fn open(path: impl AsRef<Path>) -> Result<Self, Error>

Opens an Archive from the file system while transparently undoing MacBinar encoding of the archive (not its entries).