pub struct Archive<R> { /* private fields */ }Expand description
Implementations
Sourceimpl<R> Archive<R>
impl<R> Archive<R>
Sourcepub const CREATOR_CODE: FourCC
pub const CREATOR_CODE: FourCC
Macintosh creator code used by CPT files (CPCT)
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Returns the underlying reader, note that it’s read position will have changed from when you passed it in
Sourceimpl<R: Read + Seek> Archive<R>
impl<R: Read + Seek> Archive<R>
Sourcepub fn iter(&self) -> Result<EntryIterator<R>, Error>
pub fn iter(&self) -> Result<EntryIterator<R>, Error>
Creates an iterator over all archive entries.
This method panics if another [EntryIterator] is currently alive for this archive to
avoid over sharing the underlying reader’s seek position.
Sourcepub fn verify_entry(&mut self, entry: &Entry) -> Result<(), VerificationError>
pub fn verify_entry(&mut self, entry: &Entry) -> Result<(), VerificationError>
Verifies the given entry, returning a verification error if anything goes wrong